enum DirectiveKeyword: string
Public API: explicitly declared with @visibility public.

The keywords that take one argument and store it for the generated parser.

These are the keywords Lemon handles in its WAITING_FOR_DECL_ARG state.

Recognising a keyworddoctest
\LemonParser\Ast\Declaration\DirectiveKeyword::tryFrom('extra_argument')?->name // => "ExtraArgument"

Cases

case Name = 'name'
case Include = 'include'
case Code = 'code'
case TokenDestructor = 'token_destructor'
case DefaultDestructor = 'default_destructor'
case TokenPrefix = 'token_prefix'
case SyntaxError = 'syntax_error'
case ParseAccept = 'parse_accept'
case ParseFailure = 'parse_failure'
case StackOverflow = 'stack_overflow'
case ExtraArgument = 'extra_argument'
case ExtraContext = 'extra_context'
case TokenType = 'token_type'
case DefaultType = 'default_type'
case Realloc = 'realloc'
case Free = 'free'
case StackSize = 'stack_size'
case StartSymbol = 'start_symbol'

Test cases 7

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 1
Other tests reaching this symbol 6

Relations

Static calls 1
Constant reads 1
Type declarations 1